@@ -166,6 +166,10 @@ This path is relative to `org-roam-directory'."
   :group 'org-roam
   :type 'string)
 
+(defvar org-roam-link-type "roam"
+  "Link type for org-roam nodes.
+Replaced by `id' automatically when `org-roam-link-auto-replace' is non-nil.")
+
 (defvar org-roam-node-history nil
   "Minibuffer history of nodes.")
 
@@ -767,7 +771,7 @@ The INFO, if provided, is passed to the underlying `org-roam-capture-'."
     (deactivate-mark)))
 
 ;;;;; [roam:] link
-(org-link-set-parameters "roam" :follow #'org-roam-link-follow-link)
+(org-link-set-parameters org-roam-link-type :follow #'org-roam-link-follow-link)
 (defun org-roam-link-follow-link (title-or-alias)
   "Navigate \"roam:\" link to find and open the node with TITLE-OR-ALIAS.
 Assumes that the cursor was put where the link is."
@@ -796,7 +800,7 @@ Assumes that the cursor was put where the link is."
              node)
         (goto-char (org-element-property :begin link))
         (when (and (org-in-regexp org-link-any-re 1)
-                   (string-equal type "roam")
+                   (string-equal type org-roam-link-type)
                    (setq node (save-match-data (org-roam-node-from-title-or-alias path))))
           (replace-match (org-link-make-string
                           (concat "id:" (org-roam-node-id node))
@@ -806,7 +810,7 @@ Assumes that the cursor was put where the link is."
   "Replace all \"roam:\" links in buffer with \"id:\" links."
   (interactive)
   (org-with-point-at 1
-    (while (re-search-forward org-link-bracket-re nil t)
+    (while (search-forward (concat "[[" org-roam-link-type ":") nil t)
       (org-roam-link-replace-at-point))))
 
 (add-hook 'org-roam-find-file-hook #'org-roam--replace-roam-links-on-save-h)
